@@ -2,7 +2,8 @@ package Reddit::Client;
 
 # Remember to include new version and date in the docs, or get rid of that 
 # section altogether
-our $VERSION = '1.33'; # 1.33 7/10 corrected 'edited' to not be boolean
+our $VERSION = '1.34'; # 7/30 mute and unmute 
+# 1.33 7/10 corrected 'edited' to not be boolean
 # 5/29 1.32 unban
 # 5/3 .315 submit_comment now returns fullname not id
 # 4/25 .314 4/8 1.313
@@ -847,7 +848,11 @@ sub ban {
 	}
 	# $data->{permissions} = ?
 	# type: one of (friend, moderator, moderator_invite, contributor, banned, muted, wikibanned, wikicontributor)
-	$data->{type} = 'banned';
+	if ($param{mode} eq 'mute') {
+		$data->{type} = 'muted';
+	} else {
+		$data->{type} = 'banned';
+	}
 
 	my $result = $self->api_json_request(
 		api  => API_BAN, 
@@ -857,6 +862,12 @@ sub ban {
 	return $result;
 }
 
+sub mute {
+	my ($self, %param) = @_;
+	$param{mode} = 'mute';
+	return $self->ban(%param);
+}
+
 sub unban {
 	my ($self, %param) = @_;
 	my $sub	= $param{sub} || $param{subreddit} || die "subreddit is required\n";
@@ -865,7 +876,11 @@ sub unban {
 	$data->{name}	= $param{username} || die "username is required\n";
 	# ban_context = fullname, but of what - not required
 
-	$data->{type} = 'banned';
+	if ($param{mode} eq 'mute') {
+		$data->{type} = 'muted';
+	} else {
+		$data->{type} = 'banned';
+	}
 
 	my $result = $self->api_json_request(
 		api  => API_UNBAN, 
@@ -875,6 +890,12 @@ sub unban {
 	return $result;
 }
 
+sub unmute {
+	my ($self, %param) = @_;
+	$param{mode} = 'mute';
+	return $self->unban(%param);
+}
+
 sub get_modlinks {
     my ($self, %param) = @_;
 
@@ -1802,9 +1823,9 @@ C<duration>: Duration in days. Range 1-999. If false or not provided, the ban is
 
 C<ban_message>: The message sent to the banned user. Markdown is allowed.
 
-C<reason>: A short ban reason, 100 characters max. On the website ban page, this matches the ban reason you would select from the dropdown menu. It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
+C<reason>: A short ban reason, 100 characters max. On the website ban page, this in equivalent to the ban reason you would select from the dropdown menu. (For example, "Spam".) It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
 
-C<note>: An optional note, 300 characters max. Only visible to moderators. Will be concatenated to the `reason` on the subreddit's ban page.
+C<note>: An optional note, 300 characters max. Only visible to moderators. Will be concatenated to the `reason` on the subreddit's ban page. 
 
 =back
 
@@ -2189,6 +2210,12 @@ Mark everything in your inbox as read. May take some time to complete.
 
 Return an Account object that contains information about the logged in account. Aside from static account information it contains the C<has_mail> property, which will be true if there is anything in your inbox.
 
+=item mute
+
+    mute ( username => $username, subreddit => $subreddit, [ note => $note ] )
+
+Mute a user (moderator action). Optionally leave a note that only moderators can see.
+
 =item new 
 
     new ( user_agent => $user_agent, 
@@ -2317,6 +2344,12 @@ Un-ban a user (moderator action).
 
 Unhide a post.
 
+=item unmute
+
+    unmute ( username => $username, subreddit => $subreddit )
+
+Un-mute a user (moderator action).
+
 =item unsave 
 
     unsave ( $fullname )
